@@ -77,6 +77,7 @@ pub(crate) enum Language {
     Toml,
     TypeScript,
     TypeScriptTsx,
+    Verilog,
     Vhdl,
     Xml,
     Yaml,
@@ -170,6 +171,7 @@ pub(crate) fn language_name(language: Language) -> &'static str {
         Toml => "TOML",
         TypeScript => "TypeScript",
         TypeScriptTsx => "TypeScript TSX",
+        Verilog => "Verilog",
         Vhdl => "VHDL",
         Xml => "XML",
         Yaml => "YAML",
@@ -265,6 +267,9 @@ pub(crate) fn language_globs(language: Language) -> Vec<glob::Pattern> {
             "*.xrl",
             "*.yrl",
             "Emakefile",
+            "rebar.config",
+            "rebar.config.lock",
+            "rebar.lock",
         ],
         FSharp => &["*.fs", "*.fsx", "*.fsi"],
         Gleam => &["*.gleam"],
@@ -284,6 +289,7 @@ pub(crate) fn language_globs(language: Language) -> Vec<glob::Pattern> {
             "*.gltf",
             "*.har",
             "*.ice",
+            "*.ipynb",
             "*.JSON-tmLanguage",
             "*.jsonl",
             "*.mcmeta",
@@ -367,14 +373,20 @@ pub(crate) fn language_globs(language: Language) -> Vec<glob::Pattern> {
             "Cargo.lock",
             "Gopkg.lock",
             "Pipfile",
+            "pdm.lock",
             "poetry.lock",
+            "uv.lock",
         ],
         TypeScript => &["*.ts"],
         TypeScriptTsx => &["*.tsx"],
+        Verilog => &["*.v", "*.sv", "*.vh"],
         Vhdl => &["*.vhdl", "*.vhd"],
         Xml => &[
             "*.ant",
             "*.csproj",
+            // Following GitHub, treat MJML as XML.
+            // https://documentation.mjml.io/
+            "*.mjml",
             "*.plist",
             "*.resx",
             "*.svg",
@@ -543,6 +555,7 @@ fn from_emacs_mode_header(src: &str) -> Option<Language> {
             "toml" => Some(Toml),
             "tuareg" => Some(OCaml),
             "typescript" => Some(TypeScript),
+            "verilog" => Some(Verilog),
             "vhdl" => Some(Vhdl),
             "yaml" => Some(Yaml),
             "zig" => Some(Zig),
